##
# Default values are --with empty --with sqlite3 --with mysql --with postgresql
#                    --with odbc --without oracle
# Note that, for Oracle, when enabled, the following options should
# also be given:
# --with-oracle-include=/opt/oracle/app/oracle/product/11.1.0/db_1/rdbms/public
# --with-oracle-lib=/opt/oracle/app/oracle/product/11.1.0/db_1/lib
# If the macros are defined, redefine them with the correct compilation flags.
%bcond_without empty
%bcond_without sqlite3
%bcond_without mysql
%bcond_without postgresql
%bcond_without odbc
%bcond_with oracle
%bcond_with tests
%bcond_with asan

%global _default_oracle_dir /opt/oracle/app/oracle/product/11.1.0/db_1
%{!?_with_oracle_incdir: %define _with_oracle_incdir --with-oracle-include=%{_default_oracle_dir}/rdbms/public}
%{!?_with_oracle_libdir: %define _with_oracle_libdir --with-oracle-lib=%{_default_oracle_dir}/lib}
#
##
#

%global major         4.0

%global libname       %mklibname soci_core %{major}
%global libmysql      %mklibname soci_mysql %{major}
%global libodbc       %mklibname soci_odbc %{major}
%global libpostgresql %mklibname soci_postgresql %{major}
%global libsqlite3    %mklibname soci_sqlite 3 %{major}

%global devname       %mklibname soci_core -d
%global devmysql      %mklibname soci_mysql -d
%global devodbc       %mklibname soci_odbc -d
%global devpostgresql %mklibname soci_postgresql -d
%global devsqlite3    %mklibname soci_sqlite3 -d

Name:           soci
Version:        4.0.3
Release:        %mkrel 7
Summary:        The database access library for C++ programmers
License:        Boost
URL:            https://github.com/SOCI/soci
Source0:        %{url}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Group:          Databases

# Upstream issue: https://github.com/SOCI/soci/pull/815
#Patch0:         soci-werror.patch
# Works around a false positive -Wuninitialized error exposed by LTO
Patch1:         soci-uninit.patch

BuildRequires:  dos2unix
BuildRequires:  gcc gcc-c++
BuildRequires:  cmake
BuildRequires:  ninja
BuildRequires:  boost-devel
%if %{with asan}
BuildRequires:  libasan-devel
%endif

%description
Soci is a C++ database access library that provides the illusion of embedding
SQL in regular C++ code, staying entirely within the C++ standard.

%package -n %{libname}
Summary:        The database access library for C++ programmers
Group:          System/Libraries
Provides:       %{name} = %{version}-%{release}
Provides:       %{name}%{?_isa} = %{version}-%{release}
Obsoletes:      %{name} < 4.0.3-3

%description -n %{libname}
Soci is a C++ database access library that provides the illusion of embedding
SQL in regular C++ code, staying entirely within the C++ standard.

%if %{with sqlite3}
%package -n %{libsqlite3}
Summary:        SQLite3 back-end for soci
Requires:       %{libname} = %{version}-%{release}
Provides:       %{name}-sqlite3 = %{version}-%{release}
Provides:       %{name}-sqlite3%{?_isa} = %{version}-%{release}
Obsoletes:      %{name}-sqlite3 < 4.0.3-3
BuildRequires:  pkgconfig(sqlite3)

%description -n %{libsqlite3}
This package contains the SQLite3 back-end for soci, i.e., dynamic library
specific to the SQLite3 database. If you would like to use soci in your
programs with SQLite3, you will need to install soci-sqlite3.
%endif

%if %{with_mysql}
%package -n %{libmysql}
Summary:        MySQL back-end for soci
Requires:       %{libname} = %{version}-%{release}
Provides:       %{name}-mysql = %{version}-%{release}
Provides:       %{name}-mysql%{?_isa} = %{version}-%{release}
Obsoletes:      %{name}-mysql < 4.0.3-3
BuildRequires:  mariadb-devel

%description -n %{libmysql}
This package contains the MySQL back-end for soci, i.e., dynamic library
specific to the MySQL database. If you would like to use soci in your programs
with MySQL, you will need to install soci-mysql.
%endif

%if %{with_postgresql}
%package -n %{libpostgresql}
Summary:        PostGreSQL back-end for soci
Requires:       %{libname} = %{version}-%{release}
Provides:       %{name}-postgresql = %{version}-%{release}
Provides:       %{name}-postgresql%{?_isa} = %{version}-%{release}
Obsoletes:      %{name}-postgresql < 4.0.3-3
BuildRequires:  libpq-devel

%description -n %{libpostgresql}
This package contains the PostGreSQL back-end for soci, i.e., dynamic library
specific to the PostGreSQL database. If you would like to use soci in your
programs with PostGreSQL, you will need to install soci-postgresql.
%endif

%if %{with odbc}
%package -n %{libodbc}
Summary:        ODBC back-end for soci
Requires:       %{libname} = %{version}-%{release}
Provides:       %{name}-odbc = %{version}-%{release}
Provides:       %{name}-odbc%{?_isa} = %{version}-%{release}
Obsoletes:      %{name}-odbc < 4.0.3-3
BuildRequires:  unixODBC-devel

%description -n %{libodbc}
This package contains the ODBC back-end for soci, i.e., dynamic library
specific to the ODBC connectors. If you would like to use soci in your programs
with ODBC, you will need to install soci-odbc.
%endif

%if %{with oracle}
%package -n %{liboracle}
Summary:        Oracle back-end for soci
Requires:       %{libname} = %{version}-%{release}
Provides:       %{name}-oracle = %{version}-%{release}
Provides:       %{name}-oracle%{?_isa} = %{version}-%{release}
Obsoletes:      %{name}-oracle < 4.0.3-3

%description -n %{liboracle}
This package contains the Oracle back-end for soci, i.e., dynamic library
specific to the Oracle database. If you would like to use soci in your programs
with Oracle, you will need to install soci-oracle.
%endif

%package -n %{devname}
Summary:        Header files, libraries and development documentation for soci
Group:          Development/C++
Provides:       %{name}-devel = %{version}-%{release}
Obsoletes:      %{name}-devel < 4.0.3-3
Requires:       %{libname} = %{version}-%{release}
Requires:       pkgconfig
Requires:       boost-devel

%description -n %{devname}
This package contains the header files, dynamic libraries and development
documentation for soci. If you would like to develop programs using soci, you
will need to install soci-devel.

%if %{with sqlite3}
%package -n %{devsqlite3}
Summary:        SQLite3 back-end for soci
Provides:       %{name}-sqlite3-devel = %{version}-%{release}
Obsoletes:      %{name}-sqlite3-devel < 4.0.3-3
Requires:       %{name}-devel = %{version}-%{release}
Requires:       %{name}-sqlite3 = %{version}-%{release}
Requires:       pkgconfig(sqlite3)

%description -n %{devsqlite3}
This package contains the SQLite3 back-end for soci, i.e., header files and
dynamic libraries specific to the SQLite3 database. If you would like to
develop programs using soci and SQLite3, you will need to install soci-sqlite3.
%endif

%if %{with_mysql}
%package -n %{devmysql}
Summary:        MySQL back-end for soci
Provides:       %{name}-mysql-devel = %{version}-%{release}
Obsoletes:      %{name}-mysql-devel < 4.0.3-3
Requires:       %{name}-devel = %{version}-%{release}
Requires:       %{name}-mysql = %{version}-%{release}
Requires:       mariadb-devel

%description -n %{devmysql}
This package contains the MySQL back-end for soci, i.e., header files and
dynamic libraries specific to the MySQL database. If you would like to develop
programs using soci and MySQL, you will need to install soci-mysql.
%endif

%if %{with postgresql}
%package -n %{devpostgresql}
Summary:        PostGreSQL back-end for soci
Provides:       %{name}-postgresql-devel = %{version}-%{release}
Obsoletes:      %{name}-postgresql-devel < 4.0.3-3
Requires:       %{name}-devel = %{version}-%{release}
Requires:       %{name}-postgresql = %{version}-%{release}
Requires:       libpq-devel

%description -n %{devpostgresql}
This package contains the PostGreSQL back-end for soci, i.e., header files and
dynamic libraries specific to the PostGreSQL database. If you would like to
develop programs using soci and PostGreSQL, you will need to install
soci-postgresql.
%endif

%if %{with odbc}
%package -n %{devodbc}
Summary:        ODBC back-end for soci
Provides:       %{name}-odbc-devel = %{version}-%{release}
Obsoletes:      %{name}-odbc-devel < 4.0.3-3
Requires:       %{name}-devel = %{version}-%{release}
Requires:       %{name}-odbc = %{version}-%{release}
Requires:       unixODBC-devel

%description -n %{devodbc}
This package contains the Odbc back-end for soci, i.e., header files and
dynamic libraries specific to the Odbc database. If you would like to develop
programs using soci and Odbc, you will need to install soci-odbc.
%endif

%if %{with oracle}
%package -n %{devoracle}
Summary:        Oracle back-end for soci
Provides:       %{name}-oracle-devel = %{version}-%{release}
Obsoletes:      %{name}-oracle-devel < 4.0.3-3
Requires:       %{name}-devel = %{version}-%{release}
Requires:       %{name}-oracle = %{version}-%{release}

%description -n %{devoracle}
This package contains the Oracle back-end for soci, i.e., header files and
dynamic libraries specific to the Oracle database. If you would like to develop
programs using soci and Oracle, you will need to install soci-oracle.}
%endif

%package        doc
Summary:        HTML documentation for the soci library
Group:          Documentation
BuildArch:      noarch
#BuildRequires:  tex(latex)
#BuildRequires:  doxygen, ghostscript

%description    doc
This package contains the documentation in the HTML format of the soci
library. The documentation is the same as at the soci web page.

%prep
%autosetup -p1

# Remove the spurious executable permission
chmod a-x AUTHORS README* CHANGES LICENSE_1_0.txt
find docs -type f -exec chmod a-x {} \;

# Unix ends of line
dos2unix AUTHORS README* CHANGES LICENSE_1_0.txt

%build
# Support for building tests.
%define soci_testflags -DBUILD_TESTS="NONE"
%if %{with tests}
%define soci_testflags -DSOCI_TEST=ON -DSOCI_TEST_EMPTY_CONNSTR="dummy" -DSOCI_TEST_SQLITE3_CONNSTR="test.db" -DSOCI_TEST_POSTGRESQL_CONNSTR:STRING="dbname=soci_test" -DSOCI_TEST_MYSQL_CONNSTR:STRING="db=soci_test user=mloskot password=pantera"
%endif

%cmake -GNinja \
 -DSOCI_STATIC=OFF \
 -DSOCI_SHARED=ON \
 -DSOCI_CXX11=ON \
 -DSOCI_ASAN=%{?with_asan:ON}%{!?with_asan:OFF} \
 -DSOCI_EMPTY=%{?with_empty:ON}%{!?with_empty:OFF} \
 -DSOCI_SQLITE3=%{?with_sqlite3:ON}%{!?with_sqlite3:OFF} \
 -DSOCI_POSTGRESQL=%{?with_postgresql:ON}%{!?with_postgresql:OFF} \
 -DSOCI_MYSQL=%{?with_mysql:ON}%{!?with_mysql:OFF} \
 -DSOCI_ODBC=%{?with_odbc:ON}%{!?with_odbc:OFF} \
 -DWITH_ORACLE=%{?with_oracle:ON %{?_with_oracle_incdir} %{?_with_oracle_libdir}}%{!?with_oracle:OFF} \
 %{soci_testflags}
%cmake_build

%install
%cmake_install

# CMake helpers
mkdir -p %{buildroot}%{_datadir}/%{name}
mv -f %{buildroot}%{_libdir}/cmake %{buildroot}%{_datadir}/%{name}/CMake

# Remove unpackaged files from the buildroot
rm -f %{buildroot}%{_libdir}/*.a

%if %{with tests}
%check
%ctest --exclude-regex 'soci_(odbc|mysql|postgresql)_test'
%endif


%files -n %{libname}
%license LICENSE_1_0.txt
%doc AUTHORS CHANGES README*
%{_libdir}/libsoci_core.so.%{major}{,.*}
%if %{with empty}
%{_libdir}/libsoci_empty.so.%{major}{,.*}
%endif

%if %{with sqlite3}
%files -n %{libsqlite3}
%license LICENSE_1_0.txt
%doc AUTHORS CHANGES README*
%{_libdir}/libsoci_sqlite3.so.%{major}{,.*}
%endif

%if %{with mysql}
%files -n %{libmysql}
%license LICENSE_1_0.txt
%doc AUTHORS CHANGES README*
%{_libdir}/libsoci_mysql.so.%{major}{,.*}
%endif

%if %{with postgresql}
%files -n %{libpostgresql}
%license LICENSE_1_0.txt
%doc AUTHORS CHANGES README*
%{_libdir}/libsoci_postgresql.so.%{major}{,.*}
%endif

%if %{with odbc}
%files -n %{libodbc}
%license LICENSE_1_0.txt
%doc AUTHORS CHANGES README*
%{_libdir}/libsoci_odbc.so.%{major}{,.*}
%endif

%if %{with oracle}
%files -n %{liboracle}
%license LICENSE_1_0.txt
%doc AUTHORS CHANGES README*
%{_libdir}/libsoci_oracle.so.%{major}{,.*}
%endif

%files -n %{devname}
%license LICENSE_1_0.txt
%doc AUTHORS CHANGES README*
%dir %{_includedir}/soci/
%{_includedir}/soci/*.h
%if %{with empty}
%{_includedir}/soci/empty/
%endif
%{_libdir}/libsoci_core.so
%if %{with empty}
%{_libdir}/libsoci_empty.so
%endif
%{_datadir}/soci/CMake

%if %{with sqlite3}
%files -n %{devsqlite3}
%license LICENSE_1_0.txt
%doc AUTHORS CHANGES README*
%dir %{_includedir}/soci
%{_includedir}/soci/sqlite3/
%{_libdir}/libsoci_sqlite3.so
%endif

%if %{with mysql}
%files -n %{devmysql}
%license LICENSE_1_0.txt
%doc AUTHORS CHANGES README*
%dir %{_includedir}/soci
%{_includedir}/soci/mysql/
%{_libdir}/libsoci_mysql.so
%endif

%if %{with postgresql}
%files -n %{devpostgresql}
%license LICENSE_1_0.txt
%doc AUTHORS CHANGES README*
%dir %{_includedir}/soci
%{_includedir}/soci/postgresql/
%{_libdir}/libsoci_postgresql.so
%endif

%if %{with odbc}
%files -n %{devodbc}
%license LICENSE_1_0.txt
%doc AUTHORS CHANGES README*
%dir %{_includedir}/soci
%{_includedir}/soci/odbc/
%{_libdir}/libsoci_odbc.so
%endif

%if %{with oracle}
%files -n %{devoracle}
%license LICENSE_1_0.txt
%doc AUTHORS CHANGES README*
%dir %{_includedir}/soci
%{_includedir}/soci/oracle/
%{_libdir}/libsoci_oracle.so
%endif

%files doc
%license LICENSE_1_0.txt
%doc AUTHORS CHANGES README* docs


%changelog
* Thu Oct 24 2024 daviddavid <daviddavid> 4.0.3-7.mga10
+ Revision: 2111019
- rebuild for gcc/binutils toolchain

* Fri Jun 16 2023 daviddavid <daviddavid> 4.0.3-6.mga9
+ Revision: 1962137
- fix sqlite3 dependency

* Sat Dec 24 2022 wally <wally> 4.0.3-5.mga9
+ Revision: 1926395
- build without address sanitizer support

* Sat Dec 24 2022 wally <wally> 4.0.3-4.mga9
+ Revision: 1926376
- add arched provides to libs and back-ends

* Sat Dec 24 2022 wally <wally> 4.0.3-3.mga9
+ Revision: 1926359
- libifify pkg
- drop static build
- fix soci-mysql-devel pkg requires to match with Mageia packaging
- clean .spec

* Sun Jun 26 2022 joequant <joequant> 4.0.3-2.mga9
+ Revision: 1866395
- add boost dep

* Sun Jun 26 2022 joequant <joequant> 4.0.3-1.mga9
+ Revision: 1866294
- add group
- imported package soci

